==> react-native-firebase-comment-view-1.0.0.tgz: package/lib/body.tsx <==
import React, { useEffect, useState } from 'react';

//module
import firebase from '@react-native-firebase/app';

//widget
import { FlatList, Box, Center, HStack, Icon, Pressable, Spinner, Text, VStack, Skeleton, Avatar, Radio } from 'native-base';

//function
import { TimeFormat, onSnapshot } from './function';

//data type
import { CommentBodyProps, CommentCardProps, CommentProps, commentFromJson } from './type';

const Body = (props: CommentBodyProps) => {
    const { color, isFocused, scrollEnabled, collection, doc, RenderCard } = props;

    const [loading, setLoading] = useState<boolean>(true);
    const [comment, setComment] = useState<CommentProps[]>([]);
    const [orderBy, setOrderBy] = useState<string>('asc');

    useEffect(() => {
        if (isFocused) {
            if (orderBy === 'asc' || orderBy === 'desc') {
                const AppRef = firebase
                    .firestore()
                    .collection(collection)
                    .doc(doc)
                    .collection('comment')
                    .orderBy('comment_create_date', orderBy)
                    .onSnapshot(async (snapshot) => {
                        let list = await onSnapshot({
                            snapshot: snapshot.docs,
                            onDoc: commentFromJson,
                        });

                        setComment(list);
                        setLoading(false);
                    });
                return () => AppRef();
            }
        }
    }, [collection, doc, isFocused, orderBy]);

    return (
        <>
            {loading && (
                <Box
                    safeAreaBottom
                    position="absolute"
                    top={0}
                    bottom={0}
                    left={0}
                    right={0}
                    zIndex={3}
                    bg={'#00000080'}
                    alignItems="center"
                    justifyContent="center"
                >
                    <Box bg="white" rounded="md" shadow={3}>
                        <Spinner color={color} size="sm" p={5} />
                    </Box>
                </Box>
            )}
            <HStack bg="white" space={2} padding={3} marginBottom={0.5}>
                <Text fontSize="md" color="black.200">
                    댓글
                </Text>
                <Text fontSize="md" color={color}>
                    {comment.length}
                </Text>
            </HStack>
            <VStack bg="white" space={3} padding={3}>
                <OrderByButton
                    color={color}
                    list={[
                        {
                            type: 'asc',
                            name: '등록순',
                        },
                        {
                            type: 'desc',
                            name: '최신순',
                        },
                    ]}
                    value={orderBy}
                    onChange={(type) => {
                        setOrderBy(type);
                    }}
                />
                <FlatList
                    scrollEnabled={scrollEnabled}
                    ListHeaderComponent={
                        comment.length === 0 ? (
                            <Box flex={1} safeAreaBottom>
                                <Center flex={1}>
                                    <Text fontSize="md" color="black.200" p={10}>
                                        등록된 댓글이 없습니다.
                                    </Text>
                                </Center>
                            </Box>
                        ) : undefined
                    }
                    showsVerticalScrollIndicator={false}
                    scrollEventThrottle={16}
                    data={comment}
                    renderItem={({ item, index }) => {
                        if (RenderCard) {
                            return <RenderCard key={item.key} item={item} index={index} />;
                        }
                        return <CommentCard loading={loading} key={index} item={item} index={index} />;
                    }}
                />
            </VStack>
        </>
    );
};

export default Body;

const OrderByButton = ({
    list,
    value,
    color,
    onChange,
}: {
    list: { type: string; name: string }[];
    value: string;
    color: string;
    onChange: (data: string) => void;
}) => {
    return (
        <Radio.Group
            name="OrderByButton"
            value={value}
            onChange={(value) => {
                onChange(value);
            }}
        >
            <HStack space={3}>
                {list.map((item, index) => {
                    return (
                        <Radio key={index} value={item.type} colorScheme={color} size="sm">
                            {item.name}
                        </Radio>
                    );
                })}
            </HStack>
        </Radio.Group>
    );
};

export const CommentCard = ({ loading, item, index }: CommentCardProps) => {
    return (
        <HStack space={3} marginBottom={3}>
            <Skeleton marginTop={1} w="35" h="35" rounded="full" isLoaded={!loading}>
                <Avatar marginTop={1} size="35" source={{ uri: item.writer_avatar }} />
            </Skeleton>
            <Skeleton.Text space={1} maxW="70%" isLoaded={!loading}>
                <VStack flex={1} space={1}>
                    <VStack>
                        <Text fontSize="md" color="black.200">
                            {item.writer_name}
                        </Text>
                        <HStack space={3} alignItems="center">
                            <Text color={item.writer_address === '판매자' ? 'danzi.100' : 'black.300'} fontSize="sm">
                                {item.writer_address}
                            </Text>
                            <Text color="black.300" fontSize="sm">
                                {TimeFormat({ time: item.comment_create_date, format: 'YYYY-MM-DD' })}
                            </Text>
                        </HStack>
                    </VStack>
                    <Text fontSize="md" color="black.200">
                        {item.comment_decs}
                    </Text>
                </VStack>
            </Skeleton.Text>
        </HStack>
    );
};

==> react-native-firebase-comment-view-1.0.1.tgz: package/lib/body.tsx <==
import React, { useEffect, useState } from 'react';

//module
import firebase from '@react-native-firebase/app';

//widget
import { FlatList, Box, Center, HStack, Icon, Pressable, Spinner, Text, VStack, Skeleton, Avatar, Radio } from 'native-base';

//function
import { TimeFormat, onSnapshot } from './function';

//data type
import { CommentBodyProps, CommentCardProps, CommentProps, commentFromJson } from './type';

const Body = (props: CommentBodyProps) => {
    const { color, isFocused, scrollEnabled, collection, doc, RenderCard } = props;

    const [loading, setLoading] = useState<boolean>(true);
    const [comment, setComment] = useState<CommentProps[]>([]);
    const [orderBy, setOrderBy] = useState<string>('asc');

    useEffect(() => {
        if (isFocused) {
            if (orderBy === 'asc' || orderBy === 'desc') {
                const AppRef = firebase
                    .firestore()
                    .collection(collection)
                    .doc(doc)
                    .collection('comment')
                    .orderBy('comment_create_date', orderBy)
                    .onSnapshot(async (snapshot) => {
                        let list = await onSnapshot({
                            snapshot: snapshot.docs,
                            onDoc: commentFromJson,
                        });

                        setComment(list);
                        setLoading(false);
                    });
                return () => AppRef();
            }
        }
    }, [collection, doc, isFocused, orderBy]);

    return (
        <>
            {loading && (
                <Box
                    safeAreaBottom
                    position="absolute"
                    top={0}
                    bottom={0}
                    left={0}
                    right={0}
                    zIndex={3}
                    bg={'#00000080'}
                    alignItems="center"
                    justifyContent="center"
                >
                    <Box bg="white" rounded="md" shadow={3}>
                        <Spinner color={color} size="sm" p={5} />
                    </Box>
                </Box>
            )}
            <HStack alignItems="center" justifyContent="space-between">
                <HStack bg="white" space={2} padding={3} marginBottom={0.5}>
                    <Text fontSize="md" color="black.200">
                        댓글
                    </Text>
                    <Text fontSize="md" color={color}>
                        {comment.length}
                    </Text>
                </HStack>
                <OrderByButton
                    color={color}
                    list={[
                        {
                            type: 'asc',
                            name: '등록순',
                        },
                        {
                            type: 'desc',
                            name: '최신순',
                        },
                    ]}
                    value={orderBy}
                    onChange={(type) => {
                        setOrderBy(type);
                    }}
                />
            </HStack>
            <VStack bg="white" space={3} padding={3}>
                <FlatList
                    scrollEnabled={scrollEnabled}
                    ListHeaderComponent={
                        comment.length === 0 ? (
                            <Box flex={1} safeAreaBottom>
                                <Center flex={1}>
                                    <Text fontSize="md" color="black.200" p={10}>
                                        등록된 댓글이 없습니다.
                                    </Text>
                                </Center>
                            </Box>
                        ) : undefined
                    }
                    showsVerticalScrollIndicator={false}
                    scrollEventThrottle={16}
                    data={comment}
                    renderItem={({ item, index }) => {
                        if (RenderCard) {
                            return <RenderCard key={item.key} item={item} index={index} />;
                        }
                        return <CommentCard loading={loading} key={index} item={item} index={index} />;
                    }}
                />
            </VStack>
        </>
    );
};

export default Body;

const OrderByButton = ({
    list,
    value,
    color,
    onChange,
}: {
    list: { type: string; name: string }[];
    value: string;
    color: string;
    onChange: (data: string) => void;
}) => {
    return (
        <Radio.Group
            name="OrderByButton"
            value={value}
            onChange={(value) => {
                onChange(value);
            }}
        >
            <HStack space={3}>
                {list.map((item, index) => {
                    return (
                        <Radio key={index} value={item.type} color={color} size="sm">
                            {item.name}
                        </Radio>
                    );
                })}
            </HStack>
        </Radio.Group>
    );
};

export const CommentCard = ({ loading, item, index }: CommentCardProps) => {
    return (
        <HStack space={3} marginBottom={3}>
            <Skeleton marginTop={1} w="35" h="35" rounded="full" isLoaded={!loading}>
                <Avatar marginTop={1} size="35" source={{ uri: item.writer_avatar }} />
            </Skeleton>
            <Skeleton.Text space={1} maxW="70%" isLoaded={!loading}>
                <VStack flex={1} space={1}>
                    <VStack>
                        <Text fontSize="md" color="black.200">
                            {item.writer_name}
                        </Text>
                        <HStack space={3} alignItems="center">
                            <Text color={item.writer_address === '판매자' ? 'danzi.100' : 'black.300'} fontSize="sm">
                                {item.writer_address}
                            </Text>
                            <Text color="black.300" fontSize="sm">
                                {TimeFormat({ time: item.comment_create_date, format: 'YYYY-MM-DD' })}
                            </Text>
                        </HStack>
                    </VStack>
                    <Text fontSize="md" color="black.200">
                        {item.comment_decs}
                    </Text>
                </VStack>
            </Skeleton.Text>
        </HStack>
    );
};
